@@ -1,4 +1,4 @@
-use display_info::{get_display_info, get_display_infos};
+use display_info::{get_display_info_from_point, get_display_infos};
 use std::time::Instant;
 
 fn main() {
@@ -17,7 +17,7 @@ fn main() {
       display_info.rotation
     );
   }
-  let display_info = get_display_info(100, 100).unwrap();
+  let display_info = get_display_info_from_point(100, 100).unwrap();
   println!("display_info {:?}", display_info);
   println!(
     "DisplayInfo:{} x: {} y: {} width: {} height: {} scale: {} rotation: {}\n",
