@@ -41,7 +41,7 @@ pub fn get_display_infos() -> Result<Vec<DisplayInfo>, i32> {
   }
 }
 
-pub fn get_display_info(x: i32, y: i32) -> Result<DisplayInfo, i32> {
+pub fn get_display_info_from_point(x: i32, y: i32) -> Result<DisplayInfo, i32> {
   let point = CGPoint {
     x: x as f64,
     y: y as f64,
